############# Topology-2 ###############################
# Author: Sachin Ganu 
#
#
# This script defines a sample hotspot topology
# that has one AP and 10 clients such that the clients
# experience different link qualities (reflected by the PHY
# rates)
#
# All nodes- 802.11a channel 36
# CBR UDP flow at 4 Mbps (1024 byte packets) from each client to the AP
# AP reports system throughput
############################################################


Experiment.name = "Hotspot-AP"
Experiment.project = "orbit:mapping"

######
#To define the experiment-parameters such as send rate and packet size
#These values are passed on to the traffic generator when defining the
#group properties
######
Experiment.defProperty('rate', 10000, 'KBits per second sent from sender')
Experiment.defProperty('packetSize', 1024, 'Size of packets sent from sender')

#####
# Define nodes used in experiment - A corner node is chosen as the AP
# and 10 other clients are chosen from nearby to faraway nodes so as to
# get a distribution of different PHY rates to the AP
#####
defNodes('AP1', [1,2]) {|node|
  node.image = nil  # assume the right image to be on disk
  node.prototype("test:proto:receiver", {
  'protocol' => 'udp',
  'hostname' => '192.168.1.2'

  })
  node.net.w0.type = 'a'
  node.net.w0.ip = "%192.168.%x.%y" 
  node.net.w0.essid = "verizon"  
  node.net.w0.mode = "master"  
}

#####
# First group of nearby nodes (with 54 Mbps links to AP)
#####
defNodes('group1', [[3,2],[5,3],[1,3]]){|node|
    node.image = nil  # assume the right image to be on disk
    node.prototype("test:proto:sender", {
    'destinationHost' => '192.168.1.2',
    'packetSize' => Experiment.property("packetSize"),
    'rate' => Experiment.property("rate")
  })
  node.net.w0.type = 'a'
  node.net.w0.ip = "%192.168.%x.%y" 
  node.net.w0.essid = "verizon"
  node.net.w0.mode = "Managed"
  node.net.w0.rate = "54M"
}

#####
# Second group of clients (with 24 Mbps links to AP)
#####
defNodes('group2', [[7,3],[1,7],[4,6]]){|node|
    node.image = nil  # assume the right image to be on disk
    node.prototype("test:proto:sender", {
    'destinationHost' => '192.168.1.2',
    'packetSize' => Experiment.property("packetSize"),
    'rate' => Experiment.property("rate")
  })

  node.net.w0.type = 'a'
  node.net.w0.ip = "%192.168.%x.%y" 
  node.net.w0.essid = "verizon"
  node.net.w0.mode = "Managed"
  node.net.w0.rate = "24M"
}

#####
# Third group of clients (with 12 Mbps links to AP)
#####
defNodes('group3', [[11,2],[13,5],[3,13]]){|node|
  node.image = nil  # assume the right image to be on disk
    node.prototype("test:proto:sender", {
    'destinationHost' => '192.168.1.2',
    'packetSize' => Experiment.property("packetSize"),
    'rate' => Experiment.property("rate")
  })

  node.net.w0.type = 'a'
  node.net.w0.ip = "%192.168.%x.%y" 
  node.net.w0.essid = "verizon"
  node.net.w0.mode = "Managed"
  node.net.w0.rate = "12M"
}

#####
# Fourth group of faraway clients (with 6 Mbps links to AP)
#####
defNodes('group4', [18,4]){|node|
  node.image = nil  # assume the right image to be on disk
  node.prototype("test:proto:sender", {
    'destinationHost' => '192.168.1.2',
    'packetSize' => Experiment.property("packetSize"),
    'rate' => Experiment.property("rate")
  })

  node.net.w0.type = 'a'
  node.net.w0.ip = "%192.168.%x.%y" 
  node.net.w0.essid = "verizon"
  node.net.w0.mode = "Managed"
  node.net.w0.rate = "6M"
}

defNodes('clients' , ['group1', 'group2', 'group3' , 'group4']) 
#
# Now, start the experiment
#
whenAllInstalled() {
  #Let all the client latch on to the AP cell
  wait 10

  #Start AP (receiver app)
  nodes('AP1').startApplications
  wait 5

  #Start clients (sender app)
  nodes('clients').startApplications

  #Wait for 2 minutes
  wait 120
 
  Experiment.done
}
